/*
******************************************************
* Sketch for controlling an AD ADF4113 int-N synthesiser
* over its SPI bus.
*                                                           
* This module uses the Arduino SPI library (comes bundled with  
* the Arduino IDE) to enable communication between an 
* Arduino program and an SPI  enabled peripheral chip.     
*                                                           
* The routine reads in the hex vales from the sketch and sends 
* them to the chip. The hex programming values can be generated 
* in the AD programme "Int-N PLL Software" which can be
* downloaded here http://www.analog.com/en/design-center/evaluation-hardware-and-software/evaluation-boards-kits/EVAL-ADF4113.html#eb-overview
*                                                            
* The SPI library uses pin 13 of the Arduino Uno for clock.  
* Serial data is sent out on pin 11.                                                           
* This routine uses pin 10 as the chip select for the     
* SPI device to be programmed.                                                                
******************************************************
*/
#include <SPI.h>                            //  Links prewritten SPI library into the code
void setup()
{
  pinMode(10, OUTPUT);                //  Set SPI pins to be outputs
  pinMode(11, OUTPUT);
  pinMode(13, OUTPUT);
  digitalWrite(10, HIGH);
  digitalWrite(11, HIGH);
  digitalWrite(13, HIGH);
  SPI.begin();                            //  Initialize SPI parameters
  SPI.setBitOrder(MSBFIRST);              //  MSB to be sent first
  SPI.setDataMode(SPI_MODE0);             //  Set for SPI Mode 0
  SPI.setClockDivider(SPI_CLOCK_DIV128);   //  Set clock divider (optional)
                                          //  See Arduino site or Wikipedia for more info on these settings
}
void loop()
{
  digitalWrite(10,LOW);         //  Drop chip-select to 0 
  SPI.transfer(0xDF);          //  Do SPI transfer of Init latch
  SPI.transfer(0x80);
  SPI.transfer(0x93);
  digitalWrite(10,HIGH);       //  Raise chip-select to 1
  digitalWrite(10,LOW);          
  SPI.transfer(0xDF);               //  Do SPI transfer of Function latch
  SPI.transfer(0x80);
  SPI.transfer(0x92);
  digitalWrite(10,HIGH);       //  Raise chip-select to 1
  digitalWrite(10,LOW);          
  SPI.transfer(0x00);               //  Do SPI transfer of N  (A,B) Latch
  SPI.transfer(0x54);
  SPI.transfer(0xED);
  digitalWrite(10,HIGH);       //  Raise chip-select to 1
  digitalWrite(10,LOW);          
  SPI.transfer(0x00);               //  Do SPI transfer of R latch
  SPI.transfer(0x00);
  SPI.transfer(0x80);
  digitalWrite(10,HIGH);       //  Raise chip-select to 1
  
  delay(1000);                 //  Delay loop 1 seconds (pick your time frame)
}                              //  Data will be read and sent once every 1 seconds based on this
